import vega from 'vega';
import vegaLite from 'vega-lite';
import vl from 'vega-lite-api';
import { Handler } from 'vega-tooltip';
import { config } from './config';
import { getData } from './getData';
//import { viz } from './viz';

import React, { Component, useState, useCallback } from 'react';
import ReactDOM from 'react-dom';

const viz = vl
  .markBar({ size: 100, opacity: 0.9 })
  .encode(
    vl.x().fieldN('race'),
    vl.y().count(),
    vl.color().fieldN('flee')
  )
/*creates a bar chart where each bar represents a category from the 'race' field, and the height of the bars represents the count of records
for each category. The color of the bars is determined based on the 'flee' field.*/

vl.register(vega, vegaLite, {
  view: { renderer: 'svg' },
  init: view => { view.tooltip(new Handler().call); }
});

const run = async () => {
  const marks = viz
    .data(await getData())
    .width(window.innerWidth)
    .height(window.innerHeight)
    .autosize({ type: 'fit', contains: 'padding' })
    .config(config);
  
  document.body.appendChild(await marks.render());
};
run();